package gov.usgs.earthquake.nshmp.netcdf.data;

import static com.google.common.base.Preconditions.checkState;

import java.util.EnumMap;

import gov.usgs.earthquake.nshmp.gmm.NehrpSiteClass;

/**
 * NEHRP site class to data mapper.
 *
 * @author U.S. Geological Survey
 */
public class StaticData<T> extends EnumMap<NehrpSiteClass, T> {

  public StaticData() {
    super(NehrpSiteClass.class);
  }

  StaticData(EnumMap<NehrpSiteClass, T> data) {
    super(NehrpSiteClass.class);
    putAll(data);
  }

  public static <T> Builder<T> builder() {
    return new Builder<T>();
  }

  public static class Builder<T> {
    EnumMap<NehrpSiteClass, T> data;

    private Builder() {
      data = new EnumMap<>(NehrpSiteClass.class);
    }

    public Builder<T> put(NehrpSiteClass siteClass, T data) {
      this.data.put(siteClass, data);
      return this;
    }

    public StaticData<T> build() {
      checkState(!data.isEmpty(), "Must add data");
      return new StaticData<T>(data);
    }
  }
}
